@@ -8,9 +8,9 @@ PYEXEREADME=py27910.readme.txt   # from the src package
 SYMPY=sympy-0.7.6
 
 # for day-to-day testing
-VER=2.1.0.dev
+VER=2.1.1.dev
 # for release
-#VER=2.1.0
+#VER=2.1.1
 #TAG=v${VER}
 
 
@@ -41,16 +41,18 @@ rm -rf ${WINDIR}
 rm -rf ${WINDIRTMP}
 
 
-# "make install" needs python so we make it now, then remove src from
-# the package
 cp -r octsympy ${WINDIRTMP}
 pushd ${WINDIRTMP}/src/
+make distclean
+./bootstrap
+./configure
 make
 popd
 
 # copy things to the package
 mkdir ${WINDIR}
 cp -ra ${WINDIRTMP}/inst ${WINDIR}/
+cp -ra ${WINDIRTMP}/bin ${WINDIR}/
 cp -ra ${WINDIRTMP}/NEWS ${WINDIR}/
 cp -ra ${WINDIRTMP}/CONTRIBUTORS ${WINDIR}/
 cp -ra ${WINDIRTMP}/DESCRIPTION ${WINDIR}/
@@ -58,9 +60,6 @@ cp -ra ${WINDIRTMP}/COPYING ${WINDIR}/
 cp -ra ${WINDIRTMP}/README.bundled.md ${WINDIR}/
 cp -ra ${WINDIRTMP}/matlab_smt_differences.md ${WINDIR}/
 
-# relocate the mydbpy.bat file
-mkdir ${WINDIR}/bin/
-mv ${WINDIR}/inst/mydbpy.bat ${WINDIR}/bin/
 # py.exe
 cp ${PYEXE} ${WINDIR}/bin/py.exe
 cp ${PYEXEREADME} ${WINDIR}/README.pyexe.txt
